@@ -16,14 +16,6 @@ pub use help::HelpComponent;
 pub use msg::MsgComponent;
 pub use reset::ResetComponent;
 
-///
-pub enum EventUpdate {
-    None,
-    All,
-    Diff,
-    Commands,
-}
-
 ///
 #[derive(PartialEq)]
 pub enum CommandBlocking {
@@ -42,11 +34,13 @@ pub fn visibility_blocking<T: Component>(
     }
 }
 
+///
 pub trait DrawableComponent {
     ///
     fn draw<B: Backend>(&self, f: &mut Frame<B>, rect: Rect);
 }
-///
+
+/// base component trait
 pub trait Component {
     ///
     fn commands(
@@ -54,8 +48,10 @@ pub trait Component {
         out: &mut Vec<CommandInfo>,
         force_all: bool,
     ) -> CommandBlocking;
-    ///
-    fn event(&mut self, ev: Event) -> Option<EventUpdate>;
+
+    /// returns true if event propagation needs to end (event was consumed)
+    fn event(&mut self, ev: Event) -> bool;
+
     ///
     fn focused(&self) -> bool {
         false
