@@ -9,7 +9,7 @@ use strings::commands;
 use tui::{
     backend::Backend,
     layout::{Alignment, Rect},
-    widgets::{Block, Borders, Paragraph, Text, Widget},
+    widgets::{Block, Borders, Clear, Paragraph, Text},
     Frame,
 };
 
@@ -24,7 +24,9 @@ impl DrawableComponent for MsgComponent {
         if self.visible {
             let txt = vec![Text::Raw(Cow::from(self.msg.as_str()))];
 
-            ui::Clear::new(
+            let area = ui::centered_rect_absolute(65, 25, f.size());
+            f.render_widget(Clear, area);
+            f.render_widget(
                 Paragraph::new(txt.iter())
                     .block(
                         Block::default()
@@ -33,8 +35,8 @@ impl DrawableComponent for MsgComponent {
                     )
                     .wrap(true)
                     .alignment(Alignment::Left),
-            )
-            .render(f, ui::centered_rect_absolute(65, 25, f.size()));
+                area,
+            );
         }
     }
 }
